@@ -37,6 +37,10 @@ class MultimodalDataset(torch.utils.data.Dataset):
         else:
             return [d.x for d in self.data[idx]], self.y[idx]
 
+    @property
+    def tooltips(self):
+        return self.datasets[0].tooltips
+
     def clone(self,
               x: list = None,
               y: torch.Tensor = None) -> MultimodalDataset:
