@@ -174,7 +174,7 @@ class SKLearnModel(Model):
         if dataset.y is None:
             self.__model.fit(x)
         else:
-            self.__model.fit(x, dataset.y.numpy())
+            self.__model.fit(x, dataset.y.numpy().flatten())
 
         return self
 
